package com.ejie.y41b.dao;

import java.util.List;

import com.ejie.x38.dto.Pagination;
import com.ejie.y41b.model.Motivo;
import com.ejie.y41b.model.ProdAgrupado;
import com.ejie.y41b.model.Producto;

/**
 * * MotivoDao  
 * 
 *  
 */

public interface MotivoDao {

	/**
	 * Inserts a single row in the Motivo table.
	 * 
	 * @param motivo
	 *            Motivo
	 * @return Motivo
	 */
	Motivo add(Motivo motivo);

	/**
	 * Updates a single row in the Motivo table.
	 * 
	 * @param motivo
	 *            Motivo
	 * @return Motivo
	 */
	Motivo update(Motivo motivo);

	/**
	 * Updates a single row in the Motivo table.
	 * 
	 * @param motivo
	 *            Pagination
	 * @return Motivo
	 */
	public Motivo updateFechaBaja(Motivo motivo);

	/**
	 * Finds a single row in the Motivo table.
	 * 
	 * @param motivo
	 *            Motivo
	 * @return Motivo
	 */
	Motivo find(Motivo motivo);

	/**
	 * Deletes a single row in the Motivo table.
	 * 
	 * @param motivo
	 *            Motivo
	 * @return
	 */
	void remove(Motivo motivo);

	/**
	 * Finds a List of rows in the Motivo table.
	 * 
	 * @param motivo
	 *            Motivo
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	List<Motivo> findAll(Motivo motivo, Pagination pagination);

	/**
	 * Counts rows in the Motivo table.
	 * 
	 * @param motivo
	 *            Motivo
	 * @return List
	 */
	Long findAllCount(Motivo motivo);

	/**
	 * Finds rows in the Motivo table using like.
	 * 
	 * @param motivo
	 *            Motivo
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<Motivo> findAllLike(Motivo motivo, Pagination pagination,
			Boolean startsWith);

	/**
	 * Counts rows in the Motivo table using like.
	 * 
	 * @param motivo
	 *            Motivo
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	Long findAllLikeCount(Motivo motivo, Boolean startsWith);

	/**
	 * Inserts a single row in the ProdMotivo table.
	 * 
	 * @param motivo
	 *            Motivo
	 * @return Motivo
	 */
	Motivo addProdMotivo(Motivo motivo);

	/**
	 * Deletes a single row in the ProdMotivo table.
	 * 
	 * @param motivo
	 *            Motivo
	 * @return
	 */
	void removeProdMotivo(Motivo motivo);

	/**
	 * Find a single row in the findProdMotivo Many To Many relationship.
	 * 
	 * @param motivo
	 *            Motivo
	 * @param prodagrupado
	 *            ProdAgrupado
	 * @param pagination
	 *            Pagination
	 * @return Motivo
	 */
	Motivo findProdMotivo(Motivo motivo, ProdAgrupado prodagrupado,
			Pagination pagination);

	/**
	 * Counts rows rows in the ProdMotivo table.
	 * 
	 * @param motivo
	 *            Motivo
	 * @param prodagrupado
	 *            ProdAgrupado
	 * @return Long
	 */
	Long findProdMotivoCount(Motivo motivo, ProdAgrupado prodagrupado);

	/**
	 * Finds a List of rows in the Motivo table of Producto.
	 * 
	 * @param producto
	 *            Producto
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	List<Motivo> findAllMotivoProducto(Producto producto, Pagination pagination);

	/**
	 * Finds a List of rows in the Motivo table of Producto.
	 * 
	 * @param producto
	 *            Producto
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	public List<Motivo> findAllMotivoProductoAlta(Producto producto,
			Pagination pagination);

	/**
	 * Inserts a single row in the Prod_motivo table.
	 * 
	 * @param motivo
	 *            Motivo
	 * @param codMotivoAlta
	 *            String
	 */
	public void addAllProdMotivo(Motivo motivo, String codMotivoAlta);

	/**
	 * Deletes a single row in the ProdMotivo table.
	 * 
	 * @param motivo
	 *            Motivo
	 * @return
	 */
	public void removeAllProdMotivo(Motivo motivo);
}
