package com.ejie.y41b.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.EmptyResultDataAccessException;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.PaginationManager;
import com.ejie.y41b.constantes.Y41bConstantes;
import com.ejie.y41b.model.T17Pais;
import com.ejie.y41b.model.T17PaisesIso;

/**
 * * T17PaisDaoImpl  
 * 
 *  
 */
@Repository
@Transactional
public class T17PaisDaoImpl implements T17PaisDao {
	private JdbcTemplate jdbcTemplate;
	private RowMapper<T17Pais> rwMap = new RowMapper<T17Pais>() {
		public T17Pais mapRow(ResultSet resultSet, int rowNum)
				throws SQLException {
			return new T17Pais(resultSet.getString("ID"),
					resultSet.getString("DSO"));
		}
	};

	/**
	 * Method use to set the datasource.
	 * 
	 * @param dataSource
	 *            DataSource
	 * 
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/**
	 * Inserts a single row in the T17Pais table.
	 * 
	 * @param t17pais
	 *            Pagination
	 * @return T17Pais
	 */
	public T17Pais add(T17Pais t17pais) {

		String query = "INSERT INTO T17_PAIS( ID,DS_O)" + "VALUES (?,?)";

		this.jdbcTemplate.update(query, t17pais.getId(), t17pais.getDsO());
		return t17pais;
	}

	/**
	 * Updates a single row in the T17Pais table.
	 * 
	 * @param t17pais
	 *            Pagination
	 * @return T17Pais
	 */
	public T17Pais update(T17Pais t17pais) {
		String query = "UPDATE T17_PAIS SET DS_O=? WHERE ID=?";
		this.jdbcTemplate.update(query, t17pais.getDsO(), t17pais.getId());
		return t17pais;
	}

	/**
	 * Finds a single row in the T17Pais table.
	 * 
	 * @param t17pais
	 *            Pagination
	 * @return T17Pais
	 */
	@Transactional(readOnly = true)
	public T17Pais find(T17Pais t17pais) {
		try {
			String query = "SELECT t1.ID ID, t1.DS_O DSO "
					+ "FROM T17_PAIS t1  " + "WHERE t1.ID = ?    ";
			return (T17Pais) this.jdbcTemplate.queryForObject(query, rwMap,
					t17pais.getId());
		} catch (EmptyResultDataAccessException e) {
			return new T17Pais();
		}
	}

	/**
	 * Removes a single row in the T17Pais table.
	 * 
	 * @param t17pais
	 *            Pagination
	 * 
	 */
	public void remove(T17Pais t17pais) {
		String query = "DELETE  FROM T17_PAIS WHERE ID=?";
		this.jdbcTemplate.update(query, t17pais.getId());

	}

	/**
	 * Finds a List of rows in the T17Pais table.
	 * 
	 * @param t17pais
	 *            T17Pais
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<T17Pais> findAll(T17Pais t17pais, Pagination pagination) {
		StringBuffer where = new StringBuffer(3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");
		StringBuffer query = new StringBuffer("SELECT  t1.ID ID,t1.DS_O DSO "
				+ "FROM T17_PAIS t1 ");
		if (t17pais != null && t17pais.getId() != null) {
			where.append(" AND t1.ID = ?");
			params.add(t17pais.getId());
		}
		if (t17pais != null && t17pais.getDsO() != null) {
			where.append(" AND t1.DS_O = ?");
			params.add(t17pais.getDsO());
		}
		query.append(where);

		StringBuffer order = new StringBuffer(3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}

			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}

		return (List<T17Pais>) this.jdbcTemplate.query(query.toString(), rwMap,
				params.toArray());
	}

	/**
	 * Finds a List of rows in the T17Pais table.
	 * 
	 * @param t17pais
	 *            T17Pais
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<T17Pais> findAllSinEstado(T17Pais t17pais, Pagination pagination) {
		StringBuffer where = new StringBuffer(3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");
		StringBuffer query = new StringBuffer("SELECT  t1.ID ID,t1.DS_O DSO "
				+ "FROM T17_PAIS t1 ");
		if (t17pais != null && t17pais.getId() != null) {
			where.append(" AND t1.ID = ?");
			params.add(t17pais.getId());
		}
		if (t17pais != null && t17pais.getDsO() != null) {
			where.append(" AND t1.DS_O = ?");
			params.add(t17pais.getDsO());
		}

		where.append(" AND t1.ID != ?");
		params.add(Y41bConstantes.COD_PAIS_ESTADO);

		query.append(where);

		StringBuffer order = new StringBuffer(3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}

			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}

		return (List<T17Pais>) this.jdbcTemplate.query(query.toString(), rwMap,
				params.toArray());
	}

	/**
	 * Finds a List of rows in the T17Pais table.
	 * 
	 * @param t17PaisesIso
	 *            T17PaisesIso
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<T17Pais> findAllT17PaisesIsoByAlfa2(T17PaisesIso t17PaisesIso,
			Pagination pagination) {
		StringBuffer where = new StringBuffer(3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 AND t1.DS_O=t2.DS_C ");
		StringBuffer query = new StringBuffer("SELECT  t1.ID ID,t1.DS_O DSO "
				+ "FROM T17_PAIS t1, T17_PAISES_ISO t2 ");

		if (t17PaisesIso != null && t17PaisesIso.getAlfa2() != null) {
			where.append(" and t2.ALFA2= ?");
			params.add(t17PaisesIso.getAlfa2());
		}
		query.append(where);

		StringBuffer order = new StringBuffer(3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}

			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}

		return (List<T17Pais>) this.jdbcTemplate.query(query.toString(), rwMap,
				params.toArray());
	}

	/**
	 * Counts rows in the T17Pais table.
	 * 
	 * @param t17pais
	 *            T17Pais
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(T17Pais t17pais) {

		StringBuffer where = new StringBuffer(3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1  ");

		StringBuffer query = new StringBuffer(
				"SELECT COUNT(1) FROM  T17_PAIS t1  ");
		if (t17pais != null && t17pais.getId() != null) {
			where.append(" AND t1.ID = ?");
			params.add(t17pais.getId());
		}
		if (t17pais != null && t17pais.getDsO() != null) {
			where.append(" AND t1.DS_O = ?");
			params.add(t17pais.getDsO());
		}

		query.append(where);

		return this.jdbcTemplate.queryForLong(query.toString(),
				params.toArray());

	}

	/**
	 * Finds rows in the T17Pais table using like.
	 * 
	 * @param t17pais
	 *            T17Pais
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<T17Pais> findAllLike(T17Pais t17pais, Pagination pagination,
			Boolean startsWith) {
		StringBuffer where = new StringBuffer(3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");
		StringBuffer query = new StringBuffer("SELECT  t1.ID ID,t1.DS_O DSO "
				+ "FROM T17_PAIS t1 ");
		if (t17pais != null && t17pais.getId() != null) {
			where.append(" AND UPPER(t1.ID) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(t17pais.getId().toUpperCase() + "%");
			} else {
				params.add("%" + t17pais.getId().toUpperCase() + "%");
			}
			where.append(" AND t1.ID IS NOT NULL");

		}
		if (t17pais != null && t17pais.getDsO() != null) {
			where.append(" AND UPPER(t1.DS_O) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(t17pais.getDsO().toUpperCase() + "%");
			} else {
				params.add("%" + t17pais.getDsO().toUpperCase() + "%");
			}
			where.append(" AND t1.DS_O IS NOT NULL");

		}

		query.append(where);

		StringBuffer order = new StringBuffer(3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}

			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}

		return (List<T17Pais>) this.jdbcTemplate.query(query.toString(), rwMap,
				params.toArray());
	}

}
