package com.ejie.y41b.service;

import java.sql.Blob;
import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.DataIntegrityViolationException;
import org.springframework.dao.EmptyResultDataAccessException;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.x38.dto.Pagination;
import com.ejie.y41b.adapter.Y41bDokusiAdapterService;
import com.ejie.y41b.constantes.Y41bConstantes;
import com.ejie.y41b.dao.AdjunDatosMailEstablecDao;
import com.ejie.y41b.dao.AdjunDatosMailSedeDao;
import com.ejie.y41b.dao.AdjuntardocsDao;
import com.ejie.y41b.dao.ArbdoctempDao;
import com.ejie.y41b.dao.ArbnumadhreuDao;
import com.ejie.y41b.dao.DatosMailEstablecimientoDao;
import com.ejie.y41b.dao.DatosMailSedeDao;
import com.ejie.y41b.dao.DocumentoHechoDao;
import com.ejie.y41b.dao.EstablecimArbitraDao;
import com.ejie.y41b.dao.EstablecimSectorDao;
import com.ejie.y41b.dao.EstablecimientoDao;
import com.ejie.y41b.dao.HechoDenunciadoDao;
import com.ejie.y41b.dao.SedeDao;
import com.ejie.y41b.dao.TipoDocumentoDao;
import com.ejie.y41b.model.Actividad;
import com.ejie.y41b.model.Adjuntardocs;
import com.ejie.y41b.model.Arbdoctemp;
import com.ejie.y41b.model.Descriptor;
import com.ejie.y41b.model.DocumentoHecho;
import com.ejie.y41b.model.EstTipoDoc;
import com.ejie.y41b.model.EstablecimArbitra;
import com.ejie.y41b.model.EstablecimSector;
import com.ejie.y41b.model.Establecimiento;
import com.ejie.y41b.model.EstablecimientoDetalle;
import com.ejie.y41b.model.HechoDenunciado;
import com.ejie.y41b.model.Sector;
import com.ejie.y41b.model.Sede;
import com.ejie.y41b.model.TipoDocumento;
import com.ejie.y41b.model.TipoProcedimiento;
import com.ejie.y41b.model.TramiteComun;
import com.ejie.y41b.model.dokusi.Documento;
import com.ejie.y41b.model.dokusi.User;
import com.ejie.y41b.model.platea.Procedure;
import com.ejie.y41b.utils.Y41bUIDGenerator;
import com.ejie.y41b.utils.Y41bUtils;
import com.ejie.y41b.utils.dokusi.Y41bUtilsDokusi;
import com.ejie.y41b.utils.exception.Y41bUDAException;

/**
 * * EstablecimientoServiceImpl  
 * 
 *  
 */

@Service(value = "docsEstablecimientoService")
public class DocsEstablecimientoServiceImpl implements DocsEstablecimientoService {

	// private static final Logger logger = LoggerFactory
	// .getLogger(DocsEstablecimientoServiceImpl.class);
	@Autowired
	private EstablecimientoDao establecimientoDao;
	@Autowired
	private EstablecimSectorDao establecimSectorDao;
	@Autowired
	private HechoDenunciadoDao hechoDenunciadoDao;
	@Autowired
	private EstablecimArbitraDao establecimArbitraDao;
	@Autowired
	private SedeDao sedeDao;
	@Autowired
	private AdjunDatosMailEstablecDao adjunDatosMailEstablecDao;
	@Autowired
	private DatosMailEstablecimientoDao datosMailEstablecimientoDao;
	@Autowired
	private AdjunDatosMailSedeDao adjunDatosMailSedeDao;
	@Autowired
	private DatosMailSedeDao datosMailSedeDao;
	@Autowired
	private ArbnumadhreuDao arbnumadhreuDao;
	@Autowired()
	private ArbdoctempDao arbdoctempDao;
	@Autowired()
	private DocumentoHechoDao documentoHechoDao;
	@Autowired()
	private Arbtramexp2Service arbtramexp2Service;
	@Autowired
	private TipoDocumentoDao tipoDocumentoDao;
	@Autowired
	private AdjuntardocsDao adjuntardocsDao;
	@Autowired
	private Y41bDokusiAdapterService y41bDokusiAdapterService;

	/**
	 * Inserts a single row in the Establecimiento table.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @return Establecimiento
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Establecimiento add(Establecimiento establecimiento) {
		establecimiento.setEscodigo(Y41bUIDGenerator.getInstance().generateId(Y41bConstantes.PK_SIZE));
		return this.establecimientoDao.add(establecimiento);
	}

	/**
	 * Inserts a single row in the Establecimiento table.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @param establecimArbitra
	 *            EstablecimArbitra
	 * @param establecimSector
	 *            EstablecimSector
	 * @param sedeAux
	 *            Sede
	 * @return Establecimiento
	 * @throws Exception
	 *             e
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Establecimiento addEstablecimiento(Establecimiento establecimiento, EstablecimArbitra establecimArbitra,
			EstablecimSector establecimSector, Sede sedeAux) throws Exception {
		// validacion del cif
		if (establecimiento != null && establecimiento.getEstipid() != null
				&& establecimiento.getEstipid().equals(Y41bConstantes.OTROS)) {
			if (Y41bUtils.isValidCIF(establecimiento.getEsnif()) || Y41bUtils.isValidNIF(establecimiento.getEsnif())) {
				throw new Y41bUDAException("error.establecimiento.cifValidoException", true, new Exception());
			}
		}

		boolean usadoNuevoNumeroAdhesion = false;
		int[] nuevoNumeroAdhesion = { 0, 1 };
		try {
			Establecimiento establecimientoAux = new Establecimiento();
			establecimientoAux.setEsnif(establecimiento.getEsnif());

			if (Y41bUtils.isFilled(establecimiento.getEsnif())) {
				if (establecimiento.getEssede() != null && establecimiento.getEssede().equals(Y41bConstantes.SI)) {
					List<Establecimiento> listEstablecimiento = this.establecimientoDao
							.findAllLikeEstablecimiento(establecimientoAux, null, null, false);
					if (listEstablecimiento.size() > 0) {
						boolean existeSede = false;
						String idEstablecimientoSede = null;
						for (Establecimiento estaAux : listEstablecimiento) {
							if (estaAux.getEssede() != null && estaAux.getEssede().equals(Y41bConstantes.SI)) {
								existeSede = true;
								idEstablecimientoSede = estaAux.getEscodigo();
								break;
							}
						}

						if (existeSede) {
							Establecimiento estaAux = new Establecimiento();
							estaAux.setEscodigo(idEstablecimientoSede);
							estaAux.setEssede(Y41bConstantes.NO);

							// update sede antigua como no sede
							this.establecimientoDao.updateSede(estaAux);

							this.datosMailSedeDao.removeAllDatosMailSede(estaAux);

							// eliminar sus sedes establecimiento anterior como
							// sede
							this.sedeDao.removeAllSedes(estaAux);
						}
					}
				}
			}
			if (establecimiento.getEsfeadar() != null) {
				establecimiento.setEsinadar(Y41bConstantes.VALOR_SI);
			} else {
				establecimiento.setEsinadar(Y41bConstantes.VALOR_NO);
			}
			this.establecimientoDao.add(establecimiento);

			if (establecimiento.getEsfeadar() != null) {
				establecimArbitra.setEstablecimiento(establecimiento);
				establecimArbitra.setAhcodigo(establecimiento.getEscodigo());
				nuevoNumeroAdhesion = this.arbnumadhreuDao.obtenerNumeroAdhesion();
				usadoNuevoNumeroAdhesion = true;
				establecimArbitra.setAhnrdi(Integer.valueOf(nuevoNumeroAdhesion[0]));
				if (establecimArbitra.getAhfeba() != null) {
					establecimArbitra.setAhindef(Y41bConstantes.NO);
					establecimArbitra
							.setAhfeba(Y41bUtils.addDays(establecimArbitra.getAhfere(), Y41bConstantes.NUM_30));
					establecimArbitra.setAhfere(establecimArbitra.getAhfere());
				} else {
					establecimArbitra.setAhindef(Y41bConstantes.SI);
					establecimArbitra.setAhfere(null);
					establecimArbitra.setAhfeba(null);
				}
				this.establecimArbitraDao.add(establecimArbitra);
			}

			establecimSector.getEstablecimiento().setEscodigo(establecimiento.getEscodigo());
			establecimSector.setEacodigo(Y41bUIDGenerator.getInstance().generateId(Y41bConstantes.PK_SIZE));

			this.establecimSectorDao.add(establecimSector);

			this.establecimientoDao.addEstablecimientoDescriptor(establecimiento);

			this.datosMailEstablecimientoDao.addDatosMailEstablecAdjunDatos(establecimiento);

			this.adjunDatosMailEstablecDao.removeAllAdjunDatosMailEstablec(establecimiento);

			if (establecimiento.getEssede() != null && establecimiento.getEssede().equals(Y41bConstantes.SI)) {
				this.datosMailSedeDao.removeAllDatosMailSede(establecimiento);
				this.sedeDao.removeAllSedes(establecimiento);

				for (Sede sede : establecimiento.getSedes()) {
					sede.setEscodigo(establecimiento.getEscodigo());
					sede.setIdDatosede(Y41bUIDGenerator.getInstance().generateId(Y41bConstantes.PK_SIZE));

					if (sede.getExtranjero().equalsIgnoreCase(Y41bConstantes.NO)) {
						sede.setNoraPaisId(null);
						sede.setNoraPaisNombre(null);

						if (sede.getNoraProvinciaId().equals(Y41bConstantes.CODIGO_PROVINCIA_ARABA)
								|| sede.getNoraProvinciaId().equals(Y41bConstantes.CODIGO_PROVINCIA_GIPUZKOA)
								|| sede.getNoraProvinciaId().equals(Y41bConstantes.CODIGO_PROVINCIA_BIZKAIA)) {
							sede.setDireccionNocapv(null);
						} else {
							sede.setNombreCalle(null);
							sede.setNoraCalleId(null);
							sede.setNoraPortalId(null);
							sede.setNombrePortal(null);
							sede.setNombrePiso(null);
						}
					} else {
						sede.setNoraProvinciaId(null);
						sede.setNombreProvincia(null);
						sede.setNoraMunicipioId(null);
						sede.setNombreMunicipio(null);
						sede.setNoraLocalidadId(null);
						sede.setNombreLocalidad(null);
						sede.setNoraCalleId(null);
						sede.setNombreCalle(null);
						sede.setNoraPortalId(null);
						sede.setNombrePortal(null);
						sede.setNombrePiso(null);
					}

					this.sedeDao.add(sede);

					this.datosMailSedeDao.addDatosMailSedeAdjunDatos(sede, sedeAux);
				}
				this.adjunDatosMailSedeDao.removeAllAdjunDatosMailEstablecSede(sedeAux);
			} else {
				this.sedeDao.removeAllSedes(establecimiento);
			}
		} catch (Exception e) {
			if (usadoNuevoNumeroAdhesion && nuevoNumeroAdhesion[1] == 0 && nuevoNumeroAdhesion[0] != 0) {
				// this.reutilizarNumeroAdhesion(new BigDecimal(
				// nuevoNumeroAdhesion[0]));
			}
			throw e;
		}

		return establecimiento;
	}

	/**
	 * Updates a single row in the Establecimiento table.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @return Establecimiento
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Establecimiento update(Establecimiento establecimiento) {
		return this.establecimientoDao.update(establecimiento);
	}

	/**
	 * Updates a single row in the Establecimiento table.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @param establecimArbitra
	 *            EstablecimArbitra
	 * @param establecimSector
	 *            EstablecimSector
	 * @param sedeAux
	 *            Sede
	 * @return Establecimiento
	 * @throws Exception
	 *             e
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Establecimiento updateEstablecimiento(Establecimiento establecimiento, EstablecimArbitra establecimArbitra,
			EstablecimSector establecimSector, Sede sedeAux) throws Exception {
		// validacion del cif
		if (establecimiento != null && establecimiento.getEstipid() != null
				&& establecimiento.getEstipid().equals(Y41bConstantes.OTROS)) {
			if (Y41bUtils.isValidCIF(establecimiento.getEsnif()) || Y41bUtils.isValidNIF(establecimiento.getEsnif())) {
				throw new Y41bUDAException("error.establecimiento.cifValidoException", true, new Exception());
			}
		}

		boolean usadoNuevoNumeroAdhesion = false;
		int[] nuevoNumeroAdhesion = { 0, 1 };
		try {
			if (Y41bUtils.esNullOCadenaVacia(establecimArbitra.getAhcodigo())) {
				if (establecimiento.getEsfeadar() != null) {
					establecimArbitra.setEstablecimiento(establecimiento);
					establecimArbitra.setAhcodigo(establecimiento.getEscodigo());
					nuevoNumeroAdhesion = this.arbnumadhreuDao.obtenerNumeroAdhesion();
					usadoNuevoNumeroAdhesion = true;
					establecimArbitra.setAhnrdi(Integer.valueOf(nuevoNumeroAdhesion[0]));
					this.establecimArbitraDao.add(establecimArbitra);
					establecimiento.setEsinadar(Y41bConstantes.VALOR_SI);
				} else {
					establecimiento.setEsinadar(Y41bConstantes.VALOR_NO);
				}
			} else {
				EstablecimArbitra establecimArbitraBD = this.establecimArbitraDao.find(establecimArbitra);
				establecimArbitraBD.setAhcoja(establecimArbitra.getAhcoja());
				establecimArbitraBD.setAhtelimi(establecimArbitra.getAhtelimi());
				establecimArbitraBD.setAhpetact(establecimArbitra.getAhpetact());
				establecimArbitraBD.setAhmedia(establecimArbitra.getAhmedia());
				if (establecimArbitra.getAhfeba() != null) {
					establecimArbitraBD.setAhindef(Y41bConstantes.NO);
					establecimArbitraBD.setAhfeba(establecimArbitra.getAhfeba());
					establecimArbitraBD.setAhfere(establecimArbitra.getAhfere());
				} else {
					establecimArbitraBD.setAhindef(Y41bConstantes.SI);
					establecimArbitraBD.setAhfere(null);
					establecimArbitraBD.setAhfeba(null);
				}
				if (establecimiento.getEsfeadar() != null) {
					this.establecimArbitraDao.update(establecimArbitraBD);
					establecimiento.setEsinadar(Y41bConstantes.VALOR_SI);
				} else {
					this.establecimArbitraDao.remove(establecimArbitraBD);
					establecimiento.setEsinadar(Y41bConstantes.VALOR_NO);
				}
			}
			this.establecimientoDao.update(establecimiento);

			Establecimiento establecimientoAux = new Establecimiento();
			establecimientoAux.setEsnif(establecimiento.getEsnif());

			if (Y41bUtils.isFilled(establecimiento.getEsnif())) {
				if (establecimiento.getEssede() != null && establecimiento.getEssede().equals(Y41bConstantes.SI)) {
					List<Establecimiento> listEstablecimiento = this.establecimientoDao
							.findAllLikeEstablecimiento(establecimientoAux, null, null, false);
					if (listEstablecimiento.size() > 0) {
						boolean existeSede = false;
						String idEstablecimientoSede = null;
						for (Establecimiento estaAux : listEstablecimiento) {
							if (estaAux.getEssede() != null && estaAux.getEssede().equals(Y41bConstantes.SI)) {
								if (!estaAux.getEscodigo().equals(establecimiento.getEscodigo())) {
									existeSede = true;
									idEstablecimientoSede = estaAux.getEscodigo();
									break;
								}
							}
						}

						if (existeSede) {
							Establecimiento estaAux = new Establecimiento();
							estaAux.setEscodigo(idEstablecimientoSede);
							estaAux.setEssede(Y41bConstantes.NO);

							// update sede antigua como no sede
							this.establecimientoDao.updateSede(estaAux);

							this.datosMailSedeDao.removeAllDatosMailSede(estaAux);

							// eliminar sus sedes establecimiento anterior como
							// sede
							this.sedeDao.removeAllSedes(estaAux);
						}
					}
				}
			}

			EstablecimSector establecSectorAux = (EstablecimSector) this.establecimSectorDao
					.findSectorEstablecimiento(establecimSector);

			if (Y41bUtils.isFilled(establecSectorAux.getEacodigo())) {
				this.establecimSectorDao.update(establecimSector);
			} else {
				establecimSector.setEacodigo(Y41bUIDGenerator.getInstance().generateId(Y41bConstantes.PK_SIZE));

				this.establecimSectorDao.add(establecimSector);
			}

			// Descriptores
			this.establecimientoDao.removeAllEstablecimientoDescriptor(establecimiento);
			this.establecimientoDao.addEstablecimientoDescriptor(establecimiento);

			this.datosMailEstablecimientoDao.removeAllDatosMailEstablec(establecimiento);

			this.datosMailEstablecimientoDao.addDatosMailEstablecAdjunDatos(establecimiento);

			this.adjunDatosMailEstablecDao.removeAllAdjunDatosMailEstablec(establecimiento);

			if (establecimiento.getEssede() != null && establecimiento.getEssede().equals(Y41bConstantes.SI)) {
				this.datosMailSedeDao.removeAllDatosMailSede(establecimiento);
				this.sedeDao.removeAllSedes(establecimiento);

				for (Sede sede : establecimiento.getSedes()) {
					sede.setEscodigo(establecimiento.getEscodigo());
					sede.setIdDatosede(Y41bUIDGenerator.getInstance().generateId(Y41bConstantes.PK_SIZE));

					if (sede.getExtranjero().equalsIgnoreCase(Y41bConstantes.NO)) {
						sede.setNoraPaisId(null);
						sede.setNoraPaisNombre(null);

						if (sede.getNoraProvinciaId().equals(Y41bConstantes.CODIGO_PROVINCIA_ARABA)
								|| sede.getNoraProvinciaId().equals(Y41bConstantes.CODIGO_PROVINCIA_GIPUZKOA)
								|| sede.getNoraProvinciaId().equals(Y41bConstantes.CODIGO_PROVINCIA_BIZKAIA)) {
							sede.setDireccionNocapv(null);
						} else {
							sede.setNombreCalle(null);
							sede.setNoraCalleId(null);
							sede.setNoraPortalId(null);
							sede.setNombrePortal(null);
							sede.setNombrePiso(null);
						}
					} else {
						sede.setNoraProvinciaId(null);
						sede.setNombreProvincia(null);
						sede.setNoraMunicipioId(null);
						sede.setNombreMunicipio(null);
						sede.setNoraLocalidadId(null);
						sede.setNombreLocalidad(null);
						sede.setNoraCalleId(null);
						sede.setNombreCalle(null);
						sede.setNoraPortalId(null);
						sede.setNombrePortal(null);
						sede.setNombrePiso(null);
					}

					this.sedeDao.add(sede);

					this.datosMailSedeDao.addDatosMailSedeAdjunDatos(sede, sedeAux);
				}
				this.adjunDatosMailSedeDao.removeAllAdjunDatosMailEstablecSede(sedeAux);
			} else {
				this.datosMailSedeDao.removeAllDatosMailSede(establecimiento);
				this.sedeDao.removeAllSedes(establecimiento);
			}
		} catch (Exception e) {
			if (usadoNuevoNumeroAdhesion && nuevoNumeroAdhesion[1] == 0 && nuevoNumeroAdhesion[0] != 0) {
				// this.reutilizarNumeroAdhesion(new BigDecimal(
				// nuevoNumeroAdhesion[0]));
			}
			throw e;
		}

		return establecimiento;
	}

	/**
	 * Finds a single row in the Establecimiento table.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @return Establecimiento
	 */
	public Establecimiento find(Establecimiento establecimiento) {
		Establecimiento estableci = (Establecimiento) this.establecimientoDao.find(establecimiento);

		return estableci;
	}

	/**
	 * Finds a single row in the Establecimiento table.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @return EstablecimientoDetalle
	 */
	public EstablecimientoDetalle findEstablecimiento(Establecimiento establecimiento) {
		Establecimiento estableci = (Establecimiento) this.establecimientoDao.find(establecimiento);

		StringBuffer direccionCompleta = new StringBuffer();

		if (estableci.getEsnombreCalle() != null && !estableci.getEsnombreCalle().equals("")) {
			direccionCompleta.append(estableci.getEsnombreCalle());

			if (estableci.getEsnombrePortal() != null && !estableci.getEsnombrePortal().equals("")) {
				direccionCompleta.append(", ").append(estableci.getEsnombrePortal());
			}

			if (estableci.getEsnombrePiso() != null && !estableci.getEsnombrePiso().equals("")) {
				direccionCompleta.append(" ").append(estableci.getEsnombrePiso());
			}

			if (estableci.getEsnombreMunicipio() != null && !estableci.getEsnombreMunicipio().equals("")) {
				direccionCompleta.append(" ").append(estableci.getEsnombreMunicipio());
			}

			if (estableci.getEsnombreProvincia() != null && !estableci.getEsnombreProvincia().equals("")) {
				direccionCompleta.append(" ").append(estableci.getEsnombreProvincia());
			}
		} else if (estableci.getEsdireccion_nocapv() != null && !estableci.getEsdireccion_nocapv().equals("")) {
			direccionCompleta.append(estableci.getEsdireccion_nocapv());
			if (estableci.getEsnombreMunicipio() != null && !estableci.getEsnombreMunicipio().equals("")) {
				direccionCompleta.append(" ").append(estableci.getEsnombreMunicipio());
			}
			if (estableci.getEsnombreProvincia() != null && !estableci.getEsnombreProvincia().equals("")) {
				direccionCompleta.append(" ").append(estableci.getEsnombreProvincia());
			}
		}

		estableci.setEsdireccionCompleta(direccionCompleta.toString());

		EstablecimSector establecimSector = new EstablecimSector();
		establecimSector.setEstablecimiento(estableci);
		// establecimSector.getEstablecimiento().setEscodigo(
		// estableci.getEscodigo());

		EstablecimSector establecSector = new EstablecimSector();
		Actividad actividad = new Actividad();
		Sector sector = new Sector();
		establecSector.setActividad(actividad);
		establecSector.setSector(sector);

		establecSector = (EstablecimSector) this.establecimSectorDao.findSectorEstablecimiento(establecimSector);

		EstablecimientoDetalle establecidetalle = new EstablecimientoDetalle(estableci.getEscodigo(),
				estableci.getCensoMonitor().getMocodigo(), estableci.getCensoMonitor().getMonombre(),
				estableci.getCensoMonitor().getUsuarioxlnet(), estableci.getEsnombre(), estableci.getEstipid(),
				estableci.getEsnif(), estableci.getEsnoan(), estableci.getEsnoco(), estableci.getEsnodir(),
				estableci.getEscolo(), estableci.getEsnrcopo(), estableci.getEsnrtel(), estableci.getEsnrfax(),
				estableci.getEscopa(), estableci.getEsincapr(), estableci.getEsindemp(), estableci.getEsteco(),
				estableci.getEsinadar(), estableci.getEsfeadar(), estableci.getEscoem(), null, estableci.getEsinempr(),
				estableci.getEsnrtel2(), estableci.getEsinfeba(), estableci.getEsfeba(), estableci.getEsnoap1(),
				estableci.getEsnoap2(), estableci.getEsnolo(), estableci.getEscomapv(), estableci.getEscoca(),
				estableci.getEsnopeco(), estableci.getEscoidco(), estableci.getEsinreco(), estableci.getEsfemod(),
				estableci.getEsinesco(), estableci.getEsnomu(), estableci.getEsnorep(), estableci.getEsnifrep(),
				estableci.getDtteemr(), estableci.getEscarep(), estableci.getEsteurl(), estableci.getEscooe(),
				estableci.getEsnodeco(), estableci.getEsintiar(), estableci.getEsfeplad(), estableci.getEsindeme(),
				estableci.getEsnoraPaisId(), estableci.getEsnoraPaisNombre(), estableci.getEsnoraProvinciaId(),
				estableci.getEsnombreProvincia(), estableci.getEsnoraMunicipioId(), estableci.getEsnombreMunicipio(),
				estableci.getEsnoraLocalidadId(), estableci.getEsnombreLocalidad(), estableci.getEsnoraCalleId(),
				estableci.getEsnombreCalle(), estableci.getEsnoraCpId(), estableci.getEsnombreCp(),
				estableci.getEsnoraPortalId(), estableci.getEsnombrePortal(), estableci.getEsnombrePiso(),
				estableci.getEsdireccion_nocapv(), estableci.getEsdireccionCompleta(),
				estableci.getEsexpedientesAbiertos(), establecSector.getEacodigo(),
				establecSector.getActividad().getAvcodigo(), establecSector.getActividad().getAvnombre(),
				establecSector.getActividad().getAvnombree(), establecSector.getSector().getSecodigo(),
				establecSector.getSector().getSenombre(), establecSector.getSector().getSenombree(),
				establecSector.getEainprse(), estableci.getEsextranjero(), estableci.getEssede());

		establecidetalle.setEsfeerd(estableci.getEsfeerd());

		// 0149469
		establecidetalle.setEsilocalizable(estableci.getEsilocalizable());
		establecidetalle.setEsnocolabora(estableci.getEsnocolabora());
		// 0149469
		/*
		 * Long numReclamaciones = this.hechoDenunciadoDao
		 * .findAllCount(hechodenunciado);
		 * 
		 * establecidetalle.setEsnumReclamaciones(numReclamaciones.toString());
		 */

		StringBuffer direccionAntiguaCompleta = new StringBuffer();

		String escomapv = (estableci.getEscomapv() == null) ? "" : estableci.getEscomapv();
		String esnomu = (estableci.getEsnomu() == null) ? "" : estableci.getEsnomu();
		String esnolo = (estableci.getEsnolo() == null) ? "" : estableci.getEsnolo();
		String esnodir = (estableci.getEsnodir() == null) ? "" : estableci.getEsnodir();
		String esnrcopo = (estableci.getEsnrcopo() == null) ? "" : estableci.getEsnrcopo();

		direccionAntiguaCompleta.append(escomapv).append(" ").append(esnomu).append(" ").append(esnolo).append(" ")
				.append(esnodir).append(" ").append(esnrcopo);

		establecidetalle.setDireccionAntiguaCompleta(direccionAntiguaCompleta.toString());
		try {
			EstablecimArbitra establecimArbitra = new EstablecimArbitra();
			establecimArbitra.setEstablecimiento(new Establecimiento());
			establecimArbitra.getEstablecimiento().setEscodigo(estableci.getEscodigo());
			establecimArbitra = this.establecimArbitraDao.findArbitraje(establecimArbitra);
			if (establecimArbitra != null) {
				establecidetalle.setAhcodigo(establecimArbitra.getAhcodigo());
				establecidetalle.setAhfeba(establecimArbitra.getAhfeba());
				establecidetalle.setAhfere(establecimArbitra.getAhfere());
				establecidetalle.setAhtelimi(establecimArbitra.getAhtelimi());
				establecidetalle.setAhcoja(establecimArbitra.getAhcoja());
				establecidetalle.setEsinadar(estableci.getEsinadar());
				establecidetalle.setAhindef(establecimArbitra.getAhindef());
				establecidetalle.setAhmedia(establecimArbitra.getAhmedia());
				establecidetalle.setAhnrdi(establecimArbitra.getAhnrdi().toString());
				if ("A".equals(estableci.getEsinadar())) {
					if (!Y41bUtils.esNullOCadenaVacia(establecimArbitra.getAhtelimi())) {
						establecidetalle.setEsinadar("L");
					}
				}
			}
		} catch (Exception e) {

		}

		// buscar sedes
		if (establecidetalle.getEssede() != null && establecidetalle.getEssede().equals(Y41bConstantes.SI)) {
			Sede sede = new Sede();
			sede.setEscodigo(establecidetalle.getEscodigo());

			List<Sede> listSede = this.sedeDao.findAll(sede, null);
			establecidetalle.setSedes(listSede);
		}

		List<Descriptor> listDescriptor = this.establecimientoDao.findAllEstablecimientoDescriptor(establecimiento,
				null);

		StringBuffer strIdsDescriptores = new StringBuffer();
		StringBuffer strDescsDescriptores = new StringBuffer();

		strDescsDescriptores.append("[");

		boolean firstElement = true;

		// se recorre para obtener los ids de etiquetas
		for (Descriptor descriptor : listDescriptor) {
			if (firstElement) {
				strIdsDescriptores.append(descriptor.getIdDescriptor());
				strDescsDescriptores.append(descriptor.getNombre());
				firstElement = false;
			} else {
				strIdsDescriptores.append(",").append(descriptor.getIdDescriptor());
				strDescsDescriptores.append(",").append(descriptor.getNombre());
			}
		}
		strDescsDescriptores.append("]");

		establecidetalle.setIdsDescriptores(strIdsDescriptores.toString());
		establecidetalle.setDescsDescriptores(strDescsDescriptores.toString());

		return establecidetalle;
	}

	/**
	 * Finds a List of rows in the Establecimiento table.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	public List<Establecimiento> findAll(Establecimiento establecimiento, Pagination pagination) {
		return (List<Establecimiento>) this.establecimientoDao.findAll(establecimiento, pagination);
	}

	/**
	 * Counts rows in the Establecimiento table.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @return Long
	 */
	public Long findAllCount(Establecimiento establecimiento) {
		return this.establecimientoDao.findAllCount(establecimiento);
	}

	/**
	 * Finds rows in the Establecimiento table using like.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	public List<Establecimiento> findAllLike(Establecimiento establecimiento, Pagination pagination,
			Boolean startsWith) {
		return (List<Establecimiento>) this.establecimientoDao.findAllLike(establecimiento, pagination, startsWith);
	}

	/**
	 * Finds rows in the Establecimiento table using like.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @param establecimSector
	 *            EstablecimSector
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	public List<Establecimiento> findAllLikeEstablecimiento(Establecimiento establecimiento,
			EstablecimSector establecimSector, Pagination pagination, Boolean startsWith) {

		// Control para poder paginar por un campo calculado - numeroConsulta
		if (pagination != null) {
			if (pagination.getSort() != null && pagination.getSort().equals("esdireccionCompleta")) {
				pagination.setSort("ESNOMBRE_CALLE, ESNOMBRE_PORTAL, ESNODIR ");
			}
		}

		List<Establecimiento> listEstablecimiento = this.establecimientoDao.findAllLikeEstablecimiento(establecimiento,
				establecimSector, pagination, startsWith);

		for (Establecimiento establec : listEstablecimiento) {
			// Limitaciones
			if ("A".equals(establec.getEsinadar())) {
				EstablecimArbitra establecimArbitra = new EstablecimArbitra();
				establecimArbitra.setEstablecimiento(new Establecimiento());
				establecimArbitra.getEstablecimiento().setEscodigo(establec.getEscodigo());
				establecimArbitra = this.establecimArbitraDao.findArbitraje(establecimArbitra);
				if (establecimArbitra != null) {
					if (!Y41bUtils.esNullOCadenaVacia(establecimArbitra.getAhtelimi())) {
						establec.setEsinadar("L");
					}
				}

			}
			StringBuffer direccionCompleta = new StringBuffer();

			if (establec.getEsnombreCalle() != null && !establec.getEsnombreCalle().equals("")) {
				direccionCompleta.append(establec.getEsnombreCalle());

				if (establec.getEsnombrePortal() != null && !establec.getEsnombrePortal().equals("")) {
					direccionCompleta.append(", ").append(establec.getEsnombrePortal());
				}
			} else if (establec.getEsdireccion_nocapv() != null && !establec.getEsdireccion_nocapv().equals("")) {
				direccionCompleta.append(establec.getEsdireccion_nocapv());
			} else if (establec.getEsnodir() != null && !establec.getEsnodir().equals("")) {
				direccionCompleta.append(establec.getEsnodir());
			}

			establec.setEsdireccionCompleta(direccionCompleta.toString());
		}

		return listEstablecimiento;
	}

	/**
	 * Counts rows in the Establecimiento table using like.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @param establecimSector
	 *            EstablecimSector
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	public Long findAllLikeEstablecimientoCount(Establecimiento establecimiento, EstablecimSector establecimSector,
			Boolean startsWith) {
		return this.establecimientoDao.findAllLikeEstablecimientoCount(establecimiento, establecimSector, startsWith);
	}

	/**
	 * Deletes a single row in the Establecimiento table.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Establecimiento establecimiento) {
		this.establecimientoDao.remove(establecimiento);
	}

	/**
	 * Deletes multiple rows in the Establecimiento table.
	 * 
	 * @param establecimientoList
	 *            ArrayList
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void removeMultiple(ArrayList<Establecimiento> establecimientoList) {
		for (Establecimiento establecimientoAux : establecimientoList) {
			this.establecimientoDao.remove(establecimientoAux);
		}
	}

	/**
	 * Deletes a single row in the Establecimiento table.
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @param establecimSector
	 *            EstablecimSector
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void removeEstablecimiento(Establecimiento establecimiento, EstablecimSector establecimSector) {

		try {
			HechoDenunciado hechodenunciado = new HechoDenunciado();
			Establecimiento establecimientoAux = new Establecimiento();
			establecimientoAux.setEscodigo(establecimiento.getEscodigo());
			hechodenunciado.setEstablecimiento(establecimientoAux);

			Long numExpedientesAbiertos = this.hechoDenunciadoDao.findAllExpedientesAbiertosCount(hechodenunciado);

			if (numExpedientesAbiertos > 0) {
				throw new Y41bUDAException("error.establecimientos.ExpedientesAbiertosException", true,
						new Exception());
			}

			this.datosMailEstablecimientoDao.removeAllDatosMailEstablec(establecimiento);
			this.datosMailSedeDao.removeAllDatosMailSede(establecimiento);

			// Descriptores
			this.establecimientoDao.removeAllEstablecimientoDescriptor(establecimiento);
			this.sedeDao.removeAllSedes(establecimiento);

			this.establecimSectorDao.removeSectorEstablecimiento(establecimSector);
			this.establecimientoDao.remove(establecimiento);
		} catch (DataIntegrityViolationException e) {
			throw new Y41bUDAException("error.establecimientos.DataIntegrityViolationException", true, e);
		}
	}

	/**
	 * Guardamos los cambios en la tabla final de documentos y en dokusi
	 * 
	 * @param establecimiento
	 *            Establecimiento
	 * @return
	 */

	@Transactional(rollbackFor = Throwable.class)
	public void guardarDocumentos(Establecimiento establecimiento) throws Exception {

		// // TODO Auto-generated method stub
		// ME QUEDO CON LOS DOCUMENTOS DE ARBDOCTEMP QUE NO ESTEN EN
		// ADJUNTARDOCS(SE HAN ELIMINADO)
		TramiteComun tramiteComun = new TramiteComun();
		tramiteComun.setIdExpediente(establecimiento.getEscodigo());
		tramiteComun.setIdTramite(establecimiento.getEscodigo());
		tramiteComun.setTipoProcedimiento(new TipoProcedimiento("EST"));
		List<Arbdoctemp> listArbdoctempEliminados = this.arbdoctempDao.findAllDocumentosEliminadosEst(tramiteComun,
				null);

		// // aadimos a ArbDoctemp los que no estaban todava
		// this.arbdoctempDao.addDocumentosHechoAdjuntarDocs(tramiteComun);

		// buscamos todos los registros en la tabla documentoHecho y lborramos
		// los que no esten
		DocumentoHecho documentoHecho = new DocumentoHecho();
		documentoHecho.setQ5tramite(tramiteComun.getIdTramite());
		documentoHecho.setQ5hdcodigo(tramiteComun.getIdExpediente());
		List<DocumentoHecho> listDocumentoHecho2 = this.documentoHechoDao.findAll(documentoHecho, null);

		// for (DocumentoHecho documentoHechoAux : listDocumentoHecho2) {
		// try {
		// // this.documentoHechoDao.remove(documentoHechoAux);
		// for (int i = 0; i < listArbdoctempdocs.size(); i++) {
		// if (!documentoHechoAux.getQ5codocumento().equals(
		// listArbdoctempdocs.get(i).getX5codocumento())) {
		// this.documentoHechoDao.remove(documentoHechoAux);
		// }
		// }
		//
		// } catch (DataIntegrityViolationException
		// dataIntegrityViolationException) {
		// throw new Y41bUDAException(
		// "error.solicitud.documentoAdjuntadoException", true,
		// new Exception());
		// }
		// }
		for (DocumentoHecho documentoHechoAux : listDocumentoHecho2) {
			try {
				this.documentoHechoDao.remove(documentoHechoAux);
			} catch (DataIntegrityViolationException dataIntegrityViolationException) {
				throw new Y41bUDAException("error.solicitud.documentoAdjuntadoException", true, new Exception());
			}
		}
		this.documentoHechoDao.addDocumentosHechoAdjuntarDocs(tramiteComun);

		// buscamos todos los documentos que hay en la temporal
		Arbdoctemp arbdoctemp = new Arbdoctemp();
		arbdoctemp.setX5excodigo(establecimiento.getEscodigo());
		List<Arbdoctemp> listArbdoctempdocs = this.arbdoctempDao.findAll(arbdoctemp, null);

		// for (Arbdoctemp a : listArbdoctempEliminados) {
		// for (int i = 0; i < listArbdoctempdocs.size(); i++) {
		// if (listArbdoctempEliminados.get(i).getX5codocumento()
		// .equals(a.getX5codocumento())) {
		// listArbdoctempdocs.remove(i);
		// break;
		// }
		// }
		// }

		// Subimos los documentos a dokusi
		this.registrarDocumentosDokusi(listArbdoctempdocs, establecimiento);

		// borramos los registros de la tabla temporal
		this.adjuntardocsDao.removeAdjuntarDocsTramite(tramiteComun);

		// eliminamos de dokusi los que ya nbo esten
		this.arbtramexp2Service.eliminarDocumentosDokusi(listArbdoctempEliminados);

	}

	private void registrarDocumentosDokusi(List<Arbdoctemp> listArbdoctempdocs, Establecimiento establecimiento)
			throws Exception {
		Arbdoctemp arbdoctemp = null;
		if (listArbdoctempdocs != null) {
			for (int i = 0; i < listArbdoctempdocs.size(); i++) {
				arbdoctemp = listArbdoctempdocs.get(i);
				arbdoctemp = this.arbdoctempDao.find(arbdoctemp);

				if (arbdoctemp != null) {
					DocumentoHecho documentoHecho = new DocumentoHecho();
					documentoHecho.setQ5iddocumentum(arbdoctemp.getX5iddocumentum());
					documentoHecho.setQ5idTipodoc(arbdoctemp.getX5tipodocumento());
					documentoHecho.setQ5codocumento(arbdoctemp.getX5codocumento());
					documentoHecho.setQ5nofile(arbdoctemp.getX5nofile());
					documentoHecho.setQ5origen(arbdoctemp.getX5origen());
					documentoHecho.setQ5ptcodigo(arbdoctemp.getX5ptcodigo());
					documentoHecho.setQ5datafile(arbdoctemp.getX5datafile());

					StringBuffer numeroExpediente = new StringBuffer();

					numeroExpediente.append(establecimiento.getEscodigo());

					Documento documento = new Documento();

					User user = new User();
					user.setNombre(Y41bConstantes.COD_APLICACION);
					user.setDni(Y41bConstantes.COD_APLICACION);
					documento.setUser(user);

					Procedure procedure = new Procedure();
					procedure.setIdProcedimiento(Y41bConstantes.ID_PROCEDIMIENTO_ESTABLECIMIENTOS);
					documento.setProcedure(procedure);

					documento.setOidDokusi(documentoHecho.getQ5iddocumentum());

					// Si no tiene tipo documental, metemos por defecto
					// ejgv_d_archivo
					String tipoDocumental = null;

					// if (Y41bUtils.isFilled(documentoHecho.getQ5idTipodoc()))
					// {
					// tipoDocumental = documentoHecho.getQ5idTipodoc();
					// } else {
					// de momento se lo metemos a valor fijo por que solo
					// tenemos una opcion y no damos a elegir
					tipoDocumental = "ejgv_d_resolucion_inscrip";
					// }

					documento.setTipoDocumental(tipoDocumental);

					TipoDocumento tipodocumento = new TipoDocumento();
					tipodocumento.setIdTipodoc(tipoDocumental);
					try {
						tipodocumento = this.tipoDocumentoDao.find(tipodocumento);
						if (tipodocumento != null) {
							documento.setTipoDocumento(tipodocumento.getTdnombre());
						} else {
							documento.setTipoDocumento(".");
						}
					} catch (EmptyResultDataAccessException e) {
						documento.setTipoDocumento(".");
					}
					documento.setTipoDocumento("Documento generico de Archivo");
					documento.setIdDocumento(documentoHecho.getQ5codocumento());

					// Para que sepa PLATEA que es un RTF (obligatorio)
					documento.setDescripcion(documentoHecho.getQ5tedesfile());
					documento.setNombre(documentoHecho.getQ5nofile());
					documento.setExtension(Y41bUtils.getExtensionFile(documentoHecho.getQ5nofile()));

					// Calculo el origen de DOKUSI del documento ini
					documento.setOrigenDocumento(Y41bConstantes.ORIGEN_ADMINISTRACION);

					// Expediente DOKUSI
					documento.setNumeroExpediente(numeroExpediente.toString());

					// Compruebo si tiene OID de Dokusi
					if (!Y41bUtils.isFilled(documentoHecho.getQ5iddocumentum())) {
						// si es aportacion y presencial digitalizado

						Blob contenido = documentoHecho.getQ5datafile();

						byte[] bContenido = contenido.getBytes(1, (int) contenido.length());

						documento.setBytes(Y41bUtilsDokusi.encode(bContenido));

						// Si no tiene, lo registro en Dokusi y actualizo OID
						documento = y41bDokusiAdapterService.registrarDocumentoDokusiSinLocalizar(documento);
						// Actualizo OID Dokusi en tabla documentos intermedia
						Adjuntardocs adjuntardocsAuxUpdateOID = new Adjuntardocs();

						adjuntardocsAuxUpdateOID.setThcodocumento(documento.getIdDocumento());
						adjuntardocsAuxUpdateOID.setThiddocumentum(documento.getOidDokusi());
						this.adjuntardocsDao.updateOIDDokusi(adjuntardocsAuxUpdateOID);

						// if (com.ejie.y41b.utils.Y41bUtils
						// .isDocumentoTransformable(documento)) {
						// this.adjuntardocsDao
						// .updateFechaLocalizacion(adjuntardocsAuxUpdateOID);
						// } else {
						this.adjuntardocsDao.removeBlobFromOIDDokusi(adjuntardocsAuxUpdateOID);
						// }

						documentoHecho.setQ5iddocumentum(documento.getOidDokusi());

						// Actualizo OID Dokusi en tabla documentos hecho
						// Update oid de documentum
						this.documentoHechoDao.updateOIDDokusi(documentoHecho);

						// if (com.ejie.y41b.utils.Y41bUtils
						// .isDocumentoTransformable(documento)) {
						// this.documentoHechoDao
						// .updateFechaLocalizacion(documentoHecho);
						// } else {
						this.documentoHechoDao.removeBlobFromOIDDokusi(documentoHecho);
						// }

					} else {

						DocumentoHecho documentoHechoAux = new DocumentoHecho();
						documentoHechoAux.setQ5codocumento(documento.getIdDocumento());
						documentoHechoAux = this.documentoHechoDao.findDocumentoHecho(documentoHechoAux);

						if (documentoHechoAux != null && documentoHechoAux.getQ5fechasollocalizador() == null) {
							// if (com.ejie.y41b.utils.Y41bUtils
							// .isDocumentoLocalizable(documento)
							// && (documento.getNolocalizable() == null ||
							// !documento
							// .getNolocalizable().equals(
							// Y41bConstantes.VALOR_SI))) {
							//
							// LocalizadorDocumento incorporarLocalizador = new
							// LocalizadorDocumento();
							// incorporarLocalizador.setOidDocumento(documento
							// .getOidDokusi());
							// incorporarLocalizador.setProcedure(procedure);
							// User sender = new User();
							// sender.setNombre(Y41bConstantes.COD_APLICACION);
							// sender.setDni(Y41bConstantes.COD_APLICACION);
							// incorporarLocalizador.setUser(sender);
							// incorporarLocalizador.setBoolVersion(true);
							// incorporarLocalizador.setBoolReducir(false);
							// incorporarLocalizador.setSede("");
							//
							// y41bDokusiAdapterService
							// .incorporarLocalizadorDokusi(incorporarLocalizador);
							// } else if (com.ejie.y41b.utils.Y41bUtils
							// .isDocumentoTransformable(documento)) {
							// TransformarDocumento transformarDocumento = new
							// TransformarDocumento();
							// transformarDocumento.setProcedure(procedure);
							// User sender = new User();
							// sender.setNombre(Y41bConstantes.COD_APLICACION);
							// sender.setDni(Y41bConstantes.COD_APLICACION);
							// transformarDocumento.setUser(sender);
							// transformarDocumento.setOidDocumento(documento
							// .getOidDokusi());
							//
							// y41bDokusiAdapterService
							// .transformarDocumentoDokusi(transformarDocumento);
							// }

							Adjuntardocs adjuntardocsAuxUpdateOID = new Adjuntardocs();

							adjuntardocsAuxUpdateOID.setThcodocumento(documento.getIdDocumento());

							// if (com.ejie.y41b.utils.Y41bUtils
							// .isDocumentoTransformable(documento)) {
							// this.adjuntardocsDao
							// .updateFechaLocalizacion(adjuntardocsAuxUpdateOID);
							// } else {
							this.adjuntardocsDao.removeBlobFromOIDDokusi(adjuntardocsAuxUpdateOID);
							// }

							// if (com.ejie.y41b.utils.Y41bUtils
							// .isDocumentoTransformable(documento)) {
							// this.documentoHechoDao
							// .updateFechaLocalizacion(documentoHecho);
							// } else {
							this.documentoHechoDao.removeBlobFromOIDDokusi(documentoHecho);
							// }

						}
					}
				}
			}
		}
	}

	@Override
	public List<EstTipoDoc> findAllTipoDocs() {
		// TODO Auto-generated method stub

		List<EstTipoDoc> listEstTipoDoc = this.establecimientoDao.findAllTipoDocs();

		return listEstTipoDoc;
	}

	/**
	 * Inserta los documentos en la tabla temporal de adjuntar documentacion
	 * 
	 * @param tramiteComun
	 *            TramiteComun
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void addTramiteAdjuntarDocsTableTemporal(TramiteComun tramiteComun) {
		this.adjuntardocsDao.removeAdjuntarDocsTramite(tramiteComun);
		this.arbdoctempDao.addArbAdjuntarDocsEst(tramiteComun);
	}
}
