package com.ejie.y41b.control;

import java.io.IOException;
import java.io.Writer;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.sql.Blob;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import javax.sql.rowset.serial.SerialBlob;

import org.apache.commons.lang.StringEscapeUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.x38.control.exception.ControlException;
import com.ejie.x38.control.exception.ResourceNotFoundException;
import com.ejie.x38.dto.JQGridJSONModel;
import com.ejie.x38.dto.Pagination;
import com.ejie.y41b.constantes.Y41bConstantes;
import com.ejie.y41b.model.Adjuntardocs;
import com.ejie.y41b.model.CensoMonitor;
import com.ejie.y41b.model.Decision;
import com.ejie.y41b.model.Expedien;
import com.ejie.y41b.model.Parametros;
import com.ejie.y41b.model.Perfil;
import com.ejie.y41b.model.PlantillaDecision;
import com.ejie.y41b.model.PlantillaDecisionBusqueda;
import com.ejie.y41b.model.Santramexp;

import com.ejie.y41b.model.TipoDocumento;
import com.ejie.y41b.model.TipoProcedimiento;

import com.ejie.y41b.model.TramiteComun;
import com.ejie.y41b.model.TramiteSANResolucion;

import com.ejie.y41b.service.AdjuntardocsService;
import com.ejie.y41b.service.PlantillaDecisionService;

import com.ejie.y41b.service.ExpedienService;
import com.ejie.y41b.service.ParametrosService;
import com.ejie.y41b.service.SandoctempService;
import com.ejie.y41b.service.SanexpService;
import com.ejie.y41b.service.SantramexpService;
import com.ejie.y41b.utils.Y41bUtils;
import com.ejie.y41b.utils.exception.Y41bUDAErrorManager;
import com.ejie.y41b.utils.exception.Y41bUDAException;

/**
 * * TramiteController  
 * 
 *  
 */

@Controller()
@RequestMapping(value = "/" + Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite)
@SessionAttributes({ Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite, Y41bConstantes.MODOTRAMITES_TRAMITE_K30 })
public class TramiteSANResolucionController {

	private static final Logger logger = LoggerFactory.getLogger(TramiteGenericoController.class);

	private String tipo = Y41bConstantes.TRAMITE_SANCIONES_RESOLUCION;

	private String modo = Y41bConstantes.MODOTRAMITES_TRAMITE_K30;

	@Autowired()
	private SantramexpService sanTramExpService;

	@Autowired()
	private Properties appConfiguration;

	@Autowired()
	private AdjuntardocsService adjuntardocsService;

	@Autowired()
	private SandoctempService sandoctempService;

	@Autowired()
	private PlantillaDecisionService plantillaDecisionService;

	@Autowired()
	private SanexpService sanexpService;

	@Autowired()
	private ExpedienService expedienService;

	/*
	 * --------------- Tratamiento de errores comun para los proyectos UDA.
	 * --------------------------------------------------------------------
	 */

	@Autowired()
	private Y41bUDAErrorManager errorManager;
	@Autowired()
	private ParametrosService parametrosService;

	/**
	 * Method 'udaExceptionHandle'.
	 * 
	 * @param e
	 *            Y41bUDAException
	 * @param request
	 *            HttpServletRequest
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@ExceptionHandler(Y41bUDAException.class)
	public @ResponseBody() void udaExceptionHandle(Y41bUDAException e, HttpServletRequest request,
			HttpServletResponse response) {

		response.setStatus(HttpServletResponse.SC_CONFLICT);
		Writer w = null;

		try {
			w = response.getWriter();
			w.write(this.errorManager.process(e, request));
			w.flush();
		} catch (IOException e1) {
			throw new ResourceNotFoundException("No data Found.");
		}
	}

	/*
	 * --------------- Tratamiento de errores comun para los proyectos UDA.
	 * --------------------------------------------------------------------
	 */

	/**
	 * Method 'getCreateFormAlta'.
	 * 
	 * @param codProcedimiento
	 *            String
	 * @param idExpediente
	 *            String
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "maintAlta/{codProcedimiento}/{idExpediente}", method = RequestMethod.GET)
	public ModelAndView getCreateFormAlta(@PathVariable() String codProcedimiento, @PathVariable() String idExpediente,
			Model model) {
		TramiteComun tramiteComun = new TramiteComun();
		tramiteComun.setIdExpediente(idExpediente);
		tramiteComun.setIdTramite(this.sanTramExpService.getNewPK().toString());

		TipoProcedimiento tipoProcedimiento = new TipoProcedimiento();
		tipoProcedimiento.setPcodigo(codProcedimiento);
		tramiteComun.setTipoProcedimiento(tipoProcedimiento);
		tramiteComun.setIdTipoTramite(this.tipo);
		Expedien expediente = new Expedien();
		expediente.setExcodigo(tramiteComun.getIdExpediente());
		expediente = this.expedienService.find(expediente);
		tramiteComun.setNumExpediente(expediente.getCodCompletoConPrefijo());
		model.addAttribute(Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite, tramiteComun);

		model.addAttribute(this.modo, Y41bConstantes.MODO_POPUP_ALTA);

		model.addAttribute("defaultLanguage", this.appConfiguration.get("y41bVistaWar.default.language"));
		model.addAttribute("defaultLayout", this.appConfiguration.get("y41bVistaWar.default.layout"));
		return new ModelAndView(Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite, "model", model);
	}

	/**
	 * Method 'getCreateFormMod'.
	 * 
	 * @param codProcedimiento
	 *            String
	 * @param idExpediente
	 *            String
	 * @param idTramite
	 *            String
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "maintMod/{codProcedimiento}/{idExpediente}/{idTramite}", method = RequestMethod.GET)
	public ModelAndView getCreateFormMod(@PathVariable() String codProcedimiento, @PathVariable() String idExpediente,
			@PathVariable() String idTramite, Model model) {

		TramiteComun tramiteComun = new TramiteComun();
		tramiteComun.setIdExpediente(idExpediente);
		tramiteComun.setIdTramite(idTramite);

		TipoProcedimiento tipoProcedimiento = new TipoProcedimiento();
		tipoProcedimiento.setPcodigo(codProcedimiento);

		tramiteComun.setTipoProcedimiento(tipoProcedimiento);
		tramiteComun.setIdTipoTramite(this.tipo);
		Expedien expediente = new Expedien();
		expediente.setExcodigo(tramiteComun.getIdExpediente());
		expediente = this.expedienService.find(expediente);
		tramiteComun.setNumExpediente(expediente.getCodCompletoConPrefijo());
		model.addAttribute(Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite, tramiteComun);

		model.addAttribute(this.modo, Y41bConstantes.MODO_POPUP_MODIFICACION);

		model.addAttribute("defaultLanguage", this.appConfiguration.get("y41bVistaWar.default.language"));
		model.addAttribute("defaultLayout", this.appConfiguration.get("y41bVistaWar.default.layout"));

		this.sanTramExpService.addTramiteAdjuntarDocsTableTemporal(tramiteComun);

		return new ModelAndView(Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite, "model", model);
	}

	/**
	 * Method 'editTramiteGenerico'.
	 * 
	 * @param tramite
	 *            TramiteSANResolucion
	 * @param tramiteComun
	 *            TramiteComun
	 * @param modo
	 *            String
	 * @param response
	 *            HttpServletResponse
	 * @param request
	 *            HttpServletRequest
	 * @return TramiteSANResolucion
	 */
	@RequestMapping(value = "/tramitar", method = RequestMethod.PUT)
	public @ResponseBody() TramiteSANResolucion editTramiteGenerico(@RequestBody() TramiteSANResolucion tramite,
			@ModelAttribute(value = Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite) TramiteComun tramiteComun,
			@ModelAttribute(value = Y41bConstantes.MODOTRAMITES_TRAMITE_K30) String modo, HttpServletResponse response,
			HttpServletRequest request) {
		try {

			TipoProcedimiento tipoProcedimiento = tramiteComun.getTipoProcedimiento();
			Locale locale = LocaleContextHolder.getLocale();
			String idioma = locale.getLanguage();

			HttpServletRequest httpRequest = (HttpServletRequest) request;
			HttpSession httpSession = httpRequest.getSession(false);
			CensoMonitor censoMonitor = (CensoMonitor) httpSession
					.getAttribute(Y41bConstantes.SESSIONCENSOMONITORCONNECTED);

			tramite.setInstructorEjecucion(censoMonitor);

			Date today = new Date();
			Date todayWithZeroTime = Y41bUtils.parseDate(today, locale);
			tramite.setFechaFin(todayWithZeroTime);

			if (tipoProcedimiento != null && tipoProcedimiento.getPcodigo() != null
					&& tipoProcedimiento.getPcodigo().equals(Y41bConstantes.TIPO_PROC_SANCIONES)) {
				this.sanTramExpService.addTramiteResolucion(tramite, tramiteComun, idioma, true, modo);
			}

			TramiteSANResolucionController.logger.info("Entity correctly inserted!");
			return tramite;
		} catch (Y41bUDAException e) {
			throw e;
		} catch (Exception e) {
			throw new Y41bUDAException("error.generico", true, e);
		}
	}

	/**
	 * Method 'addTramiteGenerico'.
	 * 
	 * @param tramite
	 *            TramiteSANResolucion
	 * @param tramiteComun
	 *            TramiteComun
	 * @param modo
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return TramiteSANResolucion
	 */
	@RequestMapping(value = "/guardar", method = RequestMethod.POST)
	public @ResponseBody() TramiteSANResolucion addTramiteGenerico(@RequestBody() TramiteSANResolucion tramite,
			@ModelAttribute(value = Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite) TramiteComun tramiteComun,
			@ModelAttribute(value = Y41bConstantes.MODOTRAMITES_TRAMITE_K30) String modo, HttpServletRequest request) {
		try {
			Locale locale = LocaleContextHolder.getLocale();
			String idioma = locale.getLanguage();

			HttpServletRequest httpRequest = (HttpServletRequest) request;
			HttpSession httpSession = httpRequest.getSession(false);
			CensoMonitor censoMonitor = (CensoMonitor) httpSession
					.getAttribute(Y41bConstantes.SESSIONCENSOMONITORCONNECTED);
			tramite.setInstructorEjecucion(censoMonitor);

			TipoProcedimiento tipoProcedimiento = tramiteComun.getTipoProcedimiento();

			if (tipoProcedimiento != null && tipoProcedimiento.getPcodigo() != null
					&& tipoProcedimiento.getPcodigo().equals(Y41bConstantes.TIPO_PROC_SANCIONES)) {

				this.sanTramExpService.addTramiteResolucion(tramite, tramiteComun, idioma, false, modo);

			}

			TramiteSANResolucionController.logger.info("Entity correctly inserted!");
			return tramite;
		} catch (Y41bUDAException e) {
			throw e;
		} catch (Exception e) {
			throw new Y41bUDAException("error.generico", true, e);
		}
	}

	/**
	 * Method 'getTramiteGenericoById'.
	 * 
	 * @param idTramite
	 *            String
	 * @param tramiteComun
	 *            TramiteComun
	 * @param request
	 *            HttpServletRequest
	 * @return TramiteSANAcuerdoIncoacion
	 */
	@RequestMapping(value = "/findTramite/{idTramite}", method = RequestMethod.GET)
	public @ResponseBody() TramiteSANResolucion getTramiteById(@PathVariable() String idTramite,
			@ModelAttribute(value = Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite) TramiteComun tramiteComun,
			HttpServletRequest request) {
		try {
			TipoProcedimiento tipoProcedimiento = tramiteComun.getTipoProcedimiento();

			TramiteSANResolucion tramite = new TramiteSANResolucion();
			tramite.setIdTramite(idTramite);

			HttpServletRequest httpRequest = (HttpServletRequest) request;
			HttpSession httpSession = httpRequest.getSession(false);
			CensoMonitor censoMonitor = (CensoMonitor) httpSession
					.getAttribute(Y41bConstantes.SESSIONCENSOMONITORCONNECTED);

			if (tipoProcedimiento != null && tipoProcedimiento.getPcodigo() != null
					&& tipoProcedimiento.getPcodigo().equals(Y41bConstantes.TIPO_PROC_SANCIONES)) {
				tramite = this.sanTramExpService.findTramiteResolucion(tramite, censoMonitor);
			}

			if (tramite == null) {
				throw new Exception(idTramite.toString());
			}
			return tramite;
		} catch (Y41bUDAException e) {
			throw e;
		} catch (Exception e) {
			throw new Y41bUDAException("error.generico", true, e);
		}
	}

	/**
	 * Method 'handle'.
	 * 
	 * @param e
	 *            ControlException
	 * @return String
	 */
	@ExceptionHandler()
	public @ResponseBody() String handle(ControlException e) {
		TramiteSANResolucionController.logger.warn(e.getMessage());
		return e.getMessage();
	}

	/**
	 * Method 'getAppConfiguration'.
	 * 
	 * @return appConfiguration
	 */
	public Properties getAppConfiguration() {
		return this.appConfiguration;
	}

	/**
	 * Method 'setAppConfiguration'.
	 * 
	 * @param appConfiguration
	 *            Properties
	 * @return
	 */
	public void setAppConfiguration(Properties appConfiguration) {
		this.appConfiguration = appConfiguration;
	}

	/**
	 * Method 'getAllDocsTramiteResolucion'.
	 * 
	 * @param tramiteComun
	 *            TramiteComun
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(value = "/findAllDocsTramite", method = RequestMethod.GET)
	public @ResponseBody() Object getAllDocsTramiteResolucion(
			@ModelAttribute(value = Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite) TramiteComun tramiteComun,
			HttpServletRequest request) {
		try {
			Adjuntardocs adjuntardocsFilter = new Adjuntardocs();
			adjuntardocsFilter.setThidTramite(tramiteComun.getIdTramite());
			adjuntardocsFilter.setTrpcodigo(tramiteComun.getTipoProcedimiento().getPcodigo());

			Pagination pagination = null;
			if (request.getHeader("JQGridModel") != null && request.getHeader("JQGridModel").equals("true")) {
				pagination = new Pagination();
				pagination.setPage(Long.valueOf(request.getParameter("page")));
				pagination.setRows(Long.valueOf(request.getParameter("rows")));
				pagination.setSort(request.getParameter("sidx"));
				pagination.setAscDsc(request.getParameter("sord"));

				List<Adjuntardocs> listAdjuntardocs = null;

				listAdjuntardocs = this.adjuntardocsService.findAll(adjuntardocsFilter, pagination);

				if (listAdjuntardocs == null) {
					throw new Exception("No data Found.");
				}

				Long total = this.adjuntardocsService.findAllCount(adjuntardocsFilter);
				JQGridJSONModel data = new JQGridJSONModel();
				data.setPage(request.getParameter("page"));
				data.setRecords(total.intValue());
				data.setTotal(total, pagination.getRows());
				data.setRows(listAdjuntardocs);
				return data;
			} else {
				List<Adjuntardocs> listAdjuntardocs = null;

				listAdjuntardocs = this.adjuntardocsService.findAll(adjuntardocsFilter, pagination);

				if (listAdjuntardocs == null) {
					throw new Exception("No data Found.");
				}
				return listAdjuntardocs;
			}
		} catch (Y41bUDAException e) {
			throw e;
		} catch (Exception e) {
			throw new Y41bUDAException("error.generico", true, e);
		}
	}

	// /**
	// * Method 'getAllPlantillasTramiteResolucion'.
	// *
	// * @param tramiteComun
	// * TramiteComun
	// * @param request
	// * HttpServletRequest
	// * @return String
	// */
	// @RequestMapping(value = "/findAllPlantilla", method = RequestMethod.GET)
	// public @ResponseBody()
	// Object getAllPlantillasTramiteResolucion(
	// @ModelAttribute(value =
	// Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite) TramiteComun
	// tramiteComun,
	// HttpServletRequest request) {
	// try {
	// PlantillaTramite plantillaTramite = new PlantillaTramite();
	//
	// Tramite tramite = new Tramite();
	//
	// TipoProcedimiento tipoProcedimiento = tramiteComun
	// .getTipoProcedimiento();
	//
	// plantillaTramite.setPcodigo(tipoProcedimiento.getPcodigo());
	// tramite.setTrcodigo(Y41bConstantes.TRAMITE_SANCIONES_RESOLUCION);
	// plantillaTramite.setTramite(tramite);
	//
	// Pagination pagination = null;
	// if (request.getHeader("JQGridModel") != null
	// && request.getHeader("JQGridModel").equals("true")) {
	// pagination = new Pagination();
	// pagination.setPage(Long.valueOf(request.getParameter("page")));
	// pagination.setRows(Long.valueOf(request.getParameter("rows")));
	// pagination.setSort(request.getParameter("sidx"));
	// pagination.setAscDsc(request.getParameter("sord"));
	//
	// List<PlantillaTramiteBusqueda> listPlantillaTramiteBusqueda = null;
	//
	// listPlantillaTramiteBusqueda = this.plantillaTramiteService
	// .findAllPlantillaTramite(plantillaTramite, pagination);
	//
	// if (listPlantillaTramiteBusqueda == null) {
	// throw new Exception("No data Found.");
	// }
	//
	// Long total = this.plantillaTramiteService
	// .findAllPlantillaTramiteCount(plantillaTramite);
	// JQGridJSONModel data = new JQGridJSONModel();
	// data.setPage(request.getParameter("page"));
	// data.setRecords(total.intValue());
	// data.setTotal(total, pagination.getRows());
	// data.setRows(listPlantillaTramiteBusqueda);
	// return data;
	// } else {
	// List<PlantillaTramiteBusqueda> listPlantillaTramiteBusqueda = null;
	//
	// listPlantillaTramiteBusqueda = this.plantillaTramiteService
	// .findAllPlantillaTramite(plantillaTramite, pagination);
	//
	// if (listPlantillaTramiteBusqueda == null) {
	// throw new Exception("No data Found.");
	// }
	// return listPlantillaTramiteBusqueda;
	// }
	// } catch (Y41bUDAException e) {
	// throw e;
	// } catch (Exception e) {
	// throw new Y41bUDAException("error.generico", true, e);
	// }
	// }

	// /**
	// * Method 'getByIdPlantillaResolucion'.
	// *
	// * @param ptcodigo
	// * String
	// * @param tramiteComun
	// * TramiteComun
	// * @param response
	// * HttpServletResponse
	// * @param request
	// * HttpServletRequest
	// */
	// @RequestMapping(value = "/findPlantillaResolucion/{pdcodigo}", method =
	// RequestMethod.GET)
	// public @ResponseBody()
	// void getByIdPlantillaResolucion(
	// @PathVariable() String pdcodigo,
	// @ModelAttribute(value =
	// Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite) TramiteComun
	// tramiteComun,
	// HttpServletResponse response, HttpServletRequest request) {
	// try {
	//
	// TipoProcedimiento tipoProcedimiento = tramiteComun
	// .getTipoProcedimiento();
	//
	// if (tipoProcedimiento != null
	// && tipoProcedimiento.getPcodigo() != null
	// && tipoProcedimiento.getPcodigo().equals(
	// Y41bConstantes.TIPO_PROC_SANCIONES)) {
	// PlantillaDecision plantillaDecision = new PlantillaDecision();
	// plantillaDecision.setPdcodigo(pdcodigo);
	//
	// String plantilla = this.sanexpservice.findPlantillaDecision(
	// plantillaDecision, tramiteComun);
	//
	// byte[] bContenido = plantilla.getBytes();
	//
	// plantillaDecision = this.plantillaDecisionService
	// .find(plantillaDecision);
	// String nombreFichero = new StringBuffer()
	// .append(plantillaDecision.getPdnombre()).append(".rtf")
	// .toString();
	//
	// response.setHeader("Content-Disposition",
	// "attachment; filename=" + nombreFichero + "");
	// response.setContentType("application/msword");
	// response.setContentLength(bContenido.length);
	// response.getOutputStream().write(bContenido);
	//
	// // Vaciamos el stream
	// response.getOutputStream().flush();
	// }
	//
	// } catch (Y41bUDAException e) {
	// throw e;
	// } catch (Exception e) {
	// throw new Y41bUDAException("error.generico", true, e);
	// }
	// }

	/**
	 * Method 'getByIdDocumentoResolucion'.
	 * 
	 * @param thcodocumento
	 *            Long
	 * @param tramiteComun
	 *            TramiteComun
	 * @param response
	 *            HttpServletResponse
	 */
	@RequestMapping(value = "/findDoc/{thcodocumento}", method = RequestMethod.GET)
	public @ResponseBody() void getByIdDocumentoResolucion(@PathVariable() String thcodocumento,
			@ModelAttribute(value = Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite) TramiteComun tramiteComun,
			HttpServletResponse response) {
		try {
			Adjuntardocs adjuntardocsAux = new Adjuntardocs();
			adjuntardocsAux.setThidExpediente(tramiteComun.getIdExpediente());
			adjuntardocsAux.setThidTramite(tramiteComun.getIdTramite());
			adjuntardocsAux.setThcodocumento(thcodocumento.toString());
			adjuntardocsAux.setTipoProcedimiento(tramiteComun.getTipoProcedimiento());

			adjuntardocsAux = this.adjuntardocsService.findAdjuntardocs(adjuntardocsAux);

			Blob contenido = adjuntardocsAux.getThdatafile();
			// byte[] bContenido = contenido.getBytes(1, (int)
			// contenido.length());

			// Cambiamos el objeto Response para visualizar el contenido del
			// archivo
			response.setHeader("Content-Disposition",
					"attachment; filename=\"" + StringEscapeUtils.unescapeHtml(adjuntardocsAux.getThnofile()) + "\"");
			response.setContentType(adjuntardocsAux.getThcontenttypefile());
			response.setContentLength(adjuntardocsAux.getThsizefile());
			// response.getOutputStream().write(bContenido);
			Y41bUtils.copyStream(contenido.getBinaryStream(), response.getOutputStream());

			// Vaciamos el stream
			response.getOutputStream().flush();

		} catch (Y41bUDAException e) {
			throw e;
		} catch (Exception e) {
			throw new Y41bUDAException("error.generico", true, e);
		}
	}

	/**
	 * Method 'addDocsTramiteResolucion'.
	 * 
	 * @param file
	 *            MultipartFile
	 * @param tramiteComun
	 *            TramiteComun
	 * @param response
	 *            HttpServletResponse
	 * @param request
	 *            HttpServletRequest
	 * 
	 * @return ConsultaFile
	 */
	@RequestMapping(value = "/anyadirDocsTramite", method = RequestMethod.POST)
	public @ResponseBody() List<Map<String, Object>> addDocsTramiteResolucion(
			@RequestParam(value = "files[]", required = false) MultipartFile file,
			@ModelAttribute(value = Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite) TramiteComun tramiteComun,
			HttpServletResponse response, HttpServletRequest request) {
		try {

			Adjuntardocs adjuntardocsAux = new Adjuntardocs();

			String thtedesfile = request.getParameter("thtedesfile");

			String requiereFirma = request.getParameter("requiereFirma");
			String rolFirma = null;
			if (requiereFirma != null && requiereFirma.equals("on")) {
				rolFirma = request.getParameter("rolFirma");
				requiereFirma = Y41bConstantes.SI;
			} else {
				requiereFirma = Y41bConstantes.NO;
			}

			adjuntardocsAux.setThcodocumento(this.sandoctempService.getNewPK().toString());
			adjuntardocsAux.setThorigen(Y41bConstantes.ORIGEN_SAN_APORTADO_ADMINISTRACION);

			if (Y41bConstantes.SI.equals(requiereFirma)) {
				Perfil perfilFirma = new Perfil();
				perfilFirma.setIdPerfil(rolFirma);
				adjuntardocsAux.setPerfil(perfilFirma);
				adjuntardocsAux.setThfechasolfirma(Calendar.getInstance().getTime());
				adjuntardocsAux.setThestadodocumento(Y41bConstantes.ESTADO_DOCUMENTO_PENDIENTEFIRMA);
			}

			TipoDocumento tipoDocumento = new TipoDocumento();
			tipoDocumento.setIdTipodoc(Y41bConstantes.TIPO_DOC_SAN_RESOLUCION_EXP_SANC);

			adjuntardocsAux.setTipoDocumento(tipoDocumento);

			adjuntardocsAux.setThtedesfile(thtedesfile);

			// Blob blob = new SerialBlob(file.getBytes());
			// adjuntardocsAux.setThdatafile(blob);
			adjuntardocsAux.setThdatafileinputstream(file.getInputStream());
			adjuntardocsAux.setThcontenttypefile(file.getContentType());
			adjuntardocsAux.setThnofile(file.getOriginalFilename());
			adjuntardocsAux.setThsizefile((int) file.getSize());

			adjuntardocsAux.setThidExpediente(tramiteComun.getIdExpediente());
			adjuntardocsAux.setThidTramite(tramiteComun.getIdTramite());
			adjuntardocsAux.setTipoProcedimiento(tramiteComun.getTipoProcedimiento());
			adjuntardocsAux.setThfecha(new Date());
			adjuntardocsAux.setTrpcodigo(tramiteComun.getTipoProcedimiento().getPcodigo());
			adjuntardocsAux = this.adjuntardocsService.add(adjuntardocsAux);

			TramiteSANResolucionController.logger.info("Entity correctly inserted!" + adjuntardocsAux);

			List<Map<String, Object>> filesMetaInfo = new ArrayList<Map<String, Object>>();
			filesMetaInfo.add(this.getFileReturnMap(file));
			return filesMetaInfo;

		} catch (Y41bUDAException e) {
			throw e;
		} catch (Exception e) {
			throw new Y41bUDAException("error.generico", true, e);
		}
	}

	/**
	 * Method 'remove'.
	 * 
	 * @param thcodocumento
	 *            Long
	 * @param tramiteComun
	 *            TramiteComun
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/eliminarDocsTramite/{thcodocumento}", method = RequestMethod.DELETE)
	public void remove(@PathVariable() String thcodocumento,
			@ModelAttribute(value = "adjuntardocs") TramiteComun tramiteComun, HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		try {
			Adjuntardocs adjuntardocsAux = new Adjuntardocs();
			adjuntardocsAux.setThidExpediente(tramiteComun.getIdExpediente());
			adjuntardocsAux.setThidTramite(tramiteComun.getIdTramite());
			adjuntardocsAux.setThcodocumento(thcodocumento.toString());
			adjuntardocsAux.setTipoProcedimiento(tramiteComun.getTipoProcedimiento());

			this.adjuntardocsService.remove(adjuntardocsAux);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Y41bUDAException e) {
			throw e;
		} catch (Exception e) {
			throw new Y41bUDAException("error.generico", true, e);
		}
	}

	/**
	 * 
	 * Metodos para la Gestion de Tabla de Docs Fin
	 * 
	 */

	/**
	 * 
	 * @param file
	 *            MultipartFile
	 * @return mapa
	 */
	private Map<String, Object> getFileReturnMap(MultipartFile file) {
		Map<String, Object> mapaRetorno = new HashMap<String, Object>();
		mapaRetorno.put("url", "/y41bVistaWar/" + Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite + "/guardar/"
				+ file.getOriginalFilename());
		mapaRetorno.put("name", file.getOriginalFilename());
		mapaRetorno.put("type", file.getContentType());
		mapaRetorno.put("size", file.getSize());
		mapaRetorno.put("delete_url", "/y41bVistaWar/" + Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite + "/guardar/"
				+ file.getOriginalFilename());
		mapaRetorno.put("delete_type", "DELETE");
		return mapaRetorno;
	}

	/**
	 * Method 'getAllPlantillasTramiteRegistroDecision'.
	 * 
	 * @param tramiteComun
	 *            TramiteComun
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(value = "/findAllPlantilla", method = RequestMethod.GET)
	public @ResponseBody() Object getAllPlantillasTramiteRegistroDecision(
			@ModelAttribute(value = Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite) TramiteComun tramiteComun,
			HttpServletRequest request) {
		try {
			PlantillaDecision plantillaDecision = new PlantillaDecision();

			TipoProcedimiento tipoProcedimiento = tramiteComun.getTipoProcedimiento();

			String decodigo = request.getParameter("decodigo");
			if (tipoProcedimiento != null && tipoProcedimiento.getPcodigo() != null
					&& tipoProcedimiento.getPcodigo().equals(Y41bConstantes.TIPO_PROC_SANCIONES)) {
				Decision decision = new Decision();
				decision.setDecodigo(decodigo);
				plantillaDecision.setDecision(decision);
				plantillaDecision.setPdcoor(Y41bConstantes.CODIGO_ORGANISMO_LAKUA);
			}

			List<PlantillaDecisionBusqueda> listPlantillaTramiteBusqueda = null;
			listPlantillaTramiteBusqueda = this.plantillaDecisionService
					.findAllPlantillaDecisionByDecision(plantillaDecision, null);

			if (listPlantillaTramiteBusqueda == null) {
				throw new Exception("No data Found.");
			}
			return listPlantillaTramiteBusqueda;
		} catch (Y41bUDAException e) {
			throw e;
		} catch (Exception e) {
			throw new Y41bUDAException("error.generico", true, e);
		}
	}

	/**
	 * Method 'addPlantilla'.
	 * 
	 * @param adjuntardocs
	 *            Adjuntardocs
	 * @param tramiteComun
	 *            TramiteComun
	 * @param response
	 *            HttpServletResponse
	 * @param request
	 *            HttpServletRequest
	 */
	@RequestMapping(value = "/addPlantilla", method = RequestMethod.POST)
	public @ResponseBody() void addPlantilla(@RequestBody() Adjuntardocs adjuntardocs,
			@ModelAttribute(value = Y41bConstantes.MODOTRAMITES_TRAMITE_K30_idTramite) TramiteComun tramiteComun,
			HttpServletResponse response, HttpServletRequest request) {
		try {
			TipoProcedimiento tipoProcedimiento = tramiteComun.getTipoProcedimiento();

			if (tipoProcedimiento != null && tipoProcedimiento.getPcodigo() != null
					&& tipoProcedimiento.getPcodigo().equals(Y41bConstantes.TIPO_PROC_SANCIONES)) {
				this.sanexpService.addPlantilla(adjuntardocs, tramiteComun,
						Y41bConstantes.TIPO_DOC_SAN_RESOLUCION_EXP_SANC);
			}

		} catch (Y41bUDAException e) {
			throw e;
		} catch (Exception e) {
			throw new Y41bUDAException("error.generico", true, e);
		}
	}

	/**
	 * Method 'importeResolucion'.
	 * 
	 * @param idExpediente
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(value = "/datosReduccion/{idExpediente}", method = RequestMethod.GET)
	public @ResponseBody() Santramexp getDatosReduccion(@PathVariable() String idExpediente,
			HttpServletRequest request) {
		try {
			return this.sanTramExpService.getDatosSancion(idExpediente, Y41bConstantes.TRAMITE_SANCIONES_RESOLUCION);
		} catch (Y41bUDAException e) {
			throw e;
		} catch (Exception e) {
			throw new Y41bUDAException("error.generico", true, e);
		}
	}

	/**
	 * Method 'importeResolucion'.
	 * 
	 * @param idExpediente
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(value = "/calcularImporteReduccion/{prontoPago}/{reconocimiento}/{importeInicial}", method = RequestMethod.GET)
	public @ResponseBody() BigDecimal calcularImporteReduccion(@PathVariable() String prontoPago,
			@PathVariable() String reconocimiento, @PathVariable() String importeInicial, HttpServletRequest request) {
		try {
			BigDecimal importe = new BigDecimal(importeInicial.replace('\u002c', '\u002e'));
			Parametros parametros = new Parametros();
			BigDecimal reduccion1 = new BigDecimal(0);
			BigDecimal reduccion2 = new BigDecimal(0);
			if (Y41bConstantes.VALOR_SI.equals(prontoPago)) {
				parametros.setParametro(Y41bConstantes.PORCENTAJE_REDUCCION_PRONTO_PAGO);
				parametros = this.parametrosService.find(parametros);
				if (parametros != null && parametros.getValor() != null && Y41bUtils.isNumeric(parametros.getValor())) {
					reduccion1 = importe.multiply(new BigDecimal(parametros.getValor()))
							.divide(new BigDecimal(Y41bConstantes.NUM_100));
				}
			}
			if (Y41bConstantes.VALOR_SI.equals(reconocimiento)) {
				parametros.setParametro(Y41bConstantes.PORCENTAJE_REDUCCION_RECONOCIMIENTO);
				parametros = this.parametrosService.find(parametros);
				if (parametros != null && parametros.getValor() != null && Y41bUtils.isNumeric(parametros.getValor())) {
					reduccion2 = importe.multiply(new BigDecimal(parametros.getValor()))
							.divide(new BigDecimal(Y41bConstantes.NUM_100));
				}
			}
			return importe.subtract(reduccion1).subtract(reduccion2).setScale(2, RoundingMode.DOWN);
		} catch (Y41bUDAException e) {
			throw e;
		} catch (Exception e) {
			throw new Y41bUDAException("error.generico", true, e);
		}
	}
}
